import Configstore from 'configstore';
import { fileURLToPath } from 'url';
import { dirname } from 'path';

const __filename = fileURLToPath(import.meta.url);
const __dirname = dirname(__filename);

// Create a Configstore instance
const config = new Configstore('cligitmessageai', {}, {
  globalConfigPath: true
});

// Debug helper
const DEBUG = process.env.DEBUG === 'true';
const debugLog = (...args) => {
  if (DEBUG) {
    console.log('[CONFIG]', ...args);
  }
};

export const setApiKey = (provider, key) => {
  debugLog(`Setting API key for ${provider}`);
  config.set(`${provider}.apiKey`, key);
  debugLog('Current config:', config.all);
};

export const getApiKey = (provider) => {
  debugLog(`Getting API key for ${provider}`);
  const key = config.get(`${provider}.apiKey`);
  debugLog(`API key found: ${!!key}`);
  return key;
};

export const hasApiKey = (provider) => {
  debugLog(`Checking API key for ${provider}`);
  const has = config.has(`${provider}.apiKey`);
  debugLog(`Has API key: ${has}`);
  return has;
};

export const deleteApiKey = (provider) => {
  debugLog(`Deleting API key for ${provider}`);
  config.delete(`${provider}.apiKey`);
  debugLog('Current config:', config.all);
};

export const setPreferredProvider = (provider) => {
  debugLog(`Setting preferred provider to ${provider}`);
  config.set('preferredProvider', provider);
  debugLog('Current config:', config.all);
};

export const getPreferredProvider = () => {
  debugLog('Getting preferred provider');
  const provider = config.get('preferredProvider');
  debugLog(`Preferred provider: ${provider}`);
  return provider;
};

export const setPreferredModel = (provider, model) => {
  debugLog(`Setting preferred model for ${provider} to ${model}`);
  config.set(`${provider}.preferredModel`, model);
  debugLog('Current config:', config.all);
};

export const getPreferredModel = (provider) => {
  debugLog(`Getting preferred model for ${provider}`);
  const model = config.get(`${provider}.preferredModel`);
  debugLog(`Preferred model: ${model}`);
  return model;
}; 