import simpleGit from 'simple-git';

const git = simpleGit();

export async function getUncommittedChanges() {
  try {
    // Get status of working directory
    const status = await git.status();
    
    // Get detailed diff for staged files
    const stagedDiff = await git.diff(['--cached']);
    
    // Get detailed diff for unstaged files
    const unstagedDiff = await git.diff();

    return {
      staged: status.staged,
      modified: status.modified,
      created: status.created,
      deleted: status.deleted,
      stagedDiff,
      unstagedDiff,
      isRepo: true // If we got here, it's a valid repo
    };
  } catch (error) {
    if (error.message.includes('not a git repository')) {
      return {
        staged: [],
        modified: [],
        created: [],
        deleted: [],
        stagedDiff: '',
        unstagedDiff: '',
        isRepo: false
      };
    }
    throw error;
  }
}

export async function getDiff() {
  try {
    const stagedDiff = await git.diff(['--cached', '--color']);
    const unstagedDiff = await git.diff(['--color']);
    
    if (!stagedDiff && !unstagedDiff) {
      return null;
    }

    return [
      stagedDiff ? '\nStaged Changes:\n' + stagedDiff : '',
      unstagedDiff ? '\nUnstaged Changes:\n' + unstagedDiff : ''
    ].filter(Boolean).join('\n');
  } catch (error) {
    if (error.message.includes('not a git repository')) {
      return null;
    }
    throw error;
  }
}

export async function commitChanges(message) {
  try {
    await git.commit(message);
    return true;
  } catch (error) {
    throw error;
  }
} 